"use strict";
/*!
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
var _a, _b, _c;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ignoreHttpMethodCheck = exports.finalizeConfig = void 0;
const tslib_1 = require("tslib");
const os = tslib_1.__importStar(require("os"));
function finalizeConfig(config) {
    var _a, _b;
    const escapeRegExp = (s) => s.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, '\\$1');
    config.reDisablePlugins = RegExp(`^(?:${config
        .disablePlugins.split(',')
        .map((s) => escapeRegExp(s.trim()))
        .join('|')})$`, 'i');
    const ignoreSuffix = `^.+(?:${config
        .ignoreSuffix.split(',')
        .map((s) => escapeRegExp(s.trim()))
        .join('|')})$`;
    const ignorePath = '^(?:' +
        config
            .traceIgnorePath.split(',')
            .map((s0) => s0
            .trim()
            .split('/**/')
            .map((s1) => s1
            .trim()
            .split('**')
            .map((s2) => s2
            .split('*')
            .map((s3) => s3.split('?').map(escapeRegExp).join('[^/]'))
            .join('[^/]*'))
            .join('(?:(?:[^/]+/)*[^/]+)?'))
            .join('/(?:[^/]*/)*'))
            .join('|') +
        ')$'; // replaces ","
    config.reIgnoreOperation = RegExp(`${ignoreSuffix}|${ignorePath}`);
    config.reHttpIgnoreMethod = RegExp(`^(?:${config
        .httpIgnoreMethod.split(',')
        .map((s) => s.trim())
        .join('|')})$`, 'i');
    config.customIdList = ((_a = config.customId) === null || _a === void 0 ? void 0 : _a.split(',')) || [];
    config.customIdTypeList = ((_b = config.customIdType) === null || _b === void 0 ? void 0 : _b.split('')) || [];
    config.customIdTypeList.unshift(...Array(config.customIdList.length - config.customIdTypeList.length).fill('0'));
}
exports.finalizeConfig = finalizeConfig;
const _config = {
    serviceName: process.env.SW_AGENT_NAME || 'your-nodejs-service',
    serviceInstance: process.env.SW_AGENT_INSTANCE ||
        (() => {
            return os.hostname();
        })(),
    collectorAddress: process.env.SW_AGENT_COLLECTOR_BACKEND_SERVICES || '127.0.0.1:11800',
    secure: ((_a = process.env.SW_AGENT_SECURE) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === 'true',
    authorization: process.env.SW_AGENT_AUTHENTICATION,
    maxBufferSize: Number.isSafeInteger(process.env.SW_AGENT_MAX_BUFFER_SIZE)
        ? Number.parseInt(process.env.SW_AGENT_MAX_BUFFER_SIZE, 10)
        : 1000,
    coldEndpoint: ((_b = process.env.SW_COLD_ENDPOINT) === null || _b === void 0 ? void 0 : _b.toLowerCase()) === 'true',
    disablePlugins: process.env.SW_AGENT_DISABLE_PLUGINS || '',
    ignoreSuffix: (_c = process.env.SW_IGNORE_SUFFIX) !== null && _c !== void 0 ? _c : '.jpg,.jpeg,.js,.css,.png,.bmp,.gif,.ico,.mp3,.mp4,.html,.svg',
    traceIgnorePath: process.env.SW_TRACE_IGNORE_PATH || '',
    httpIgnoreMethod: process.env.SW_HTTP_IGNORE_METHOD || '',
    sqlTraceParameters: (process.env.SW_SQL_TRACE_PARAMETERS || '').toLowerCase() === 'true',
    sqlParametersMaxLength: Math.trunc(Math.max(0, Number(process.env.SW_SQL_PARAMETERS_MAX_LENGTH))) || 512,
    mongoTraceParameters: (process.env.SW_MONGO_TRACE_PARAMETERS || '').toLowerCase() === 'true',
    mongoParametersMaxLength: Math.trunc(Math.max(0, Number(process.env.SW_MONGO_PARAMETERS_MAX_LENGTH))) || 512,
    awsLambdaFlush: (process.env.SW_AWSLAMBDA_FLUSH || 'true').toLowerCase() === 'true',
    reDisablePlugins: RegExp(''),
    reIgnoreOperation: RegExp(''),
    reHttpIgnoreMethod: RegExp(''),
    // customize
    customIdList: [],
    customIdTypeList: [],
    // dumpfile storage
    dumpFilePath: os.tmpdir(),
};
exports.default = _config;
function ignoreHttpMethodCheck(method) {
    return Boolean(method.match(_config.reHttpIgnoreMethod));
}
exports.ignoreHttpMethodCheck = ignoreHttpMethodCheck;
//# sourceMappingURL=AgentConfig.js.map